@@ -1,10 +1,10 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 describe WPScan::Finders::MainTheme::UrlsInHomepage do
   subject(:finder) { described_class.new(target) }
   let(:target)     { WPScan::Target.new(url) }
   let(:url)        { 'http://wp.lab/' }
-  let(:fixtures)   { File.join(FINDERS_FIXTURES, 'main_theme', 'urls_in_homepage') }
+  let(:fixtures)   { FINDERS_FIXTURES.join('main_theme', 'urls_in_homepage') }
 
   it_behaves_like 'App::Finders::WpItems::URLsInHomepage' do
     let(:type)                { 'themes' }
@@ -17,14 +17,14 @@ describe WPScan::Finders::MainTheme::UrlsInHomepage do
   describe '#passive' do
     before do
       stub_request(:get, /.*.css/)
-      stub_request(:get, target.url).to_return(body: File.read(File.join(fixtures, 'found.html')))
+      stub_request(:get, target.url).to_return(body: File.read(fixtures.join('found.html')))
     end
 
     it 'returns the expected Themes' do
       @expected = []
 
       { 'twentyfifteen' => 6, 'yolo' => 4, 'test' => 2 }.each do |slug, confidence|
-        @expected << WPScan::Theme.new(
+        @expected << WPScan::Model::Theme.new(
           slug, target, found_by: 'Urls In Homepage (Passive Detection)', confidence: confidence
         )
       end
