@@ -1,4 +1,4 @@
-require 'spec_helper'
+# frozen_string_literal: true
 
 describe WPScan::Vulnerability do
   subject(:vuln)   { described_class.new(title, references) }
